@@ -5,7 +5,7 @@
 
 
 from .npu import api, predict, compile, train, export, upload_data
-from . import vision, optim, loss
+from . import vision, optim, loss, metrics
 from .core import DataLoader
 from .version import __version__, _module
 
