@@ -12,6 +12,7 @@ class DataLoader(object):
 
     def __init__(self, dl):
         self.dl = dl
+        self.shape = []
 
     def __str__(self):
         return self.dl
@@ -28,6 +29,11 @@ class DataLoader(object):
 
     def hash(self):
         data_part = next(self.numpy())
+        if not self.shape:
+            self.shape = [s.shape for s in data_part]
+        else:
+            for i, s in enumerate(self.shape):
+                s[0] += data_part[i][0]
 
         def get_size(byte_list):
             return sum(len(d) for d in byte_list)
