@@ -1,8 +1,7 @@
 import time
 
 import requests
-from progress.bar import ChargingBar
-from progress.spinner import PixelSpinner
+from tqdm import tqdm
 
 from .web.urls import TASK_STATUS_URL
 
@@ -28,7 +27,7 @@ class Task:
         self.task_state = PENDING
         self.callback = callback
         self.cache = None
-        self._metrics = {}
+        self._logs = {}
         if self.callback:
             t = threading.Thread(target=self.callback_thread)
             t.start()
@@ -37,26 +36,21 @@ class Task:
             print("Started {0}. View status at https://dashboard.neuro-ai.co.uk/tasks/{1}".format(self.task_type.lower(), task_id))
 
     def wait(self, show_progress=False):
-        if show_progress:
-            bar = ChargingBar('Training', suffix=bar_suffix)
-        else:
-            spinner = PixelSpinner('Task in Progress ')
-        while not self.finished():
-            time.sleep(0.1)
-            if show_progress:
-                bar.goto(self.progress*100)
-            else:
-                spinner.next()
-        if self.task_state == FAILURE:
-            self.update(include_result=True)
-            raise Exception("ERROR for task {}: {}".format(self.task_id, self.task_result))
-        if self.task_state == STOPPED:
-            print("Task has been stopped.")
-        if show_progress:
-            bar.goto(100)
-            bar.finish()
-        else:
-            spinner.finish()
+        if self.finished():
+            return
+        with tqdm(desc=self.task_type, total=100,
+                  bar_format="{desc}: {percentage:.1f}%|{bar}| remaining: {remaining} || elapsed: {elapsed} ") as bar:
+            while not self.finished():
+                time.sleep(0.1)
+                bar.n = self.progress * 100
+                bar.refresh()
+            if self.task_state == FAILURE:
+                self.update(include_result=True)
+                raise Exception("ERROR for task {}: {}".format(self.task_id, self.task_result))
+            if self.task_state == STOPPED:
+                print("Task has been stopped.")
+                return
+            bar.n = 100
 
     def callback_thread(self):
         self.get_result()
@@ -78,7 +72,7 @@ class Task:
         if "result" in response:
             self.task_result = response["result"]
         if "metrics" in response:
-            self._metrics = response["metrics"]
+            self._logs = response["metrics"]
 
     def __str__(self):
         return str(self.get_result())
@@ -87,8 +81,8 @@ class Task:
         self.update()
         return self.task_state in TASK_DONE_LIST
 
-    def metrics(self):
+    def logs(self):
         self.get_result()
-        return self._metrics
+        return self._logs
 
 
