@@ -1,13 +1,11 @@
-# @wait_task
 import os
 import re
 
 import requests
 
-from .common import getToken
+from .common import getToken, check_model_type
 from .Task import Task
 from .web.urls import EXPORT_URL
-from .Model import Model
 
 
 def export(model, path):
@@ -20,25 +18,20 @@ def export(model, path):
 
 def exportApi(model, path):
     params = {"token": getToken()}
-    if isinstance(model, Model):
-        params["model_name"] = model.name
-    elif isinstance(model, str):
-        params["model_name"] = model
-    elif model != "":
-        params["modelId"] = model
+    check_model_type(model, params)
     response = requests.get(EXPORT_URL, params=params, stream=True)
     if response.status_code == 200:
         d = response.headers['content-disposition']
         filename = re.findall("filename=(.+)", d)[0]
-        print(filename)
-        with open(os.path.join(path, filename), "wb") as file:
+        filepath = os.path.join(path, filename)
+        with open(filepath, "wb") as file:
             for chunk in response.iter_content(chunk_size=1024):
                 # writing one chunk at a time to file
                 if chunk:
                     file.write(chunk)
         print("Model exported.")
+        return filepath
     else:
         raise Exception("{}".format(response.content))
-    return True
 
 
